pub struct AtomicRef<'b, T: ?Sized + 'b> { /* private fields */ }
A wrapper type for an immutably borrowed value from an AtomicRefCell<T>.
Make a new AtomicRef for a component of the borrowed data.
Make a new AtomicRef for an optional component of the borrowed data.
Formats the value using the given formatter.
Read more
The resulting type after dereferencing.
Dereferences the value.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.