Struct atomic_refcell::AtomicRefCell
[−]
[src]
pub struct AtomicRefCell<T: ?Sized> { /* fields omitted */ }
A threadsafe analogue to RefCell.
Methods
impl<T> AtomicRefCell<T>[src]
fn new(value: T) -> AtomicRefCell<T>
Creates a new AtomicRefCell containing value.
fn into_inner(self) -> T
Consumes the AtomicRefCell, returning the wrapped value.
impl<T: ?Sized> AtomicRefCell<T>[src]
fn borrow(&self) -> AtomicRef<T>
Immutably borrows the wrapped value.
fn borrow_mut(&self) -> AtomicRefMut<T>
Mutably borrows the wrapped value.
fn as_ptr(&self) -> *mut T
Returns a raw pointer to the underlying data in this cell.
External synchronization is needed to avoid data races when dereferencing the pointer.